You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ode.apache.org by ms...@apache.org on 2006/10/24 06:43:18 UTC

svn commit: r467239 [5/7] - in /incubator/ode/trunk: ./ axis2-examples/ axis2-war/ axis2/ axis2/src/main/java/org/apache/ode/axis2/ bpel-api-jca/ bpel-api/ bpel-api/src/main/java/org/apache/ode/bpel/capi/ bpel-api/src/main/java/org/apache/ode/bpel/xsl/...

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/PropertyAliasImpl.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/PropertyAliasImpl.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/PropertyAliasImpl.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias.java Mon Oct 23 21:43:09 2006
@@ -16,146 +16,78 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
-
-import org.apache.ode.bom.api.Query;
-import org.apache.ode.utils.NSContext;
+package org.apache.ode.bpel.compiler.bom;
 
 import java.io.Serializable;
 
 import javax.wsdl.extensions.ExtensibilityElement;
 import javax.xml.namespace.QName;
 
+import org.apache.ode.utils.NSContext;
+import org.w3c.dom.Element;
 
 /**
- * WSDL extension element for a BPEL <code>&lt;propertyAlias&gt;</code> element.
- * @see org.apache.ode.bom.wsdl.PropertyAliasSerializer_11
+ * WSDL extension element for a BPEL <code>&lt;propertyAlias&gt;</code>
+ * element.
+ * 
+ * @see org.apache.ode.bpel.compiler.wsdl.PropertyAliasSerializer_11
  */
-class PropertyAliasImpl implements PropertyAlias, ExtensibilityElement, Serializable {
-	
-	private static final long serialVersionUID = -1L;
-
-  private QName _propertyName;
-  private QName _messageType;
-  private String _part;
-  private Query _query;
-  private NSContext _nsc;
-  private QName _elementType;
-
-  /**
-   * @see javax.wsdl.extensions.ExtensibilityElement#setElementType(javax.xml.namespace.QName)
-   */
-  public void setElementType(QName arg0) {
-    _elementType = arg0;
-  }
-
-  /**
-   * @see javax.wsdl.extensions.ExtensibilityElement#getElementType()
-   */
-  public QName getElementType() {
-    return _elementType;
-  }
-
-  /**
-   * Set the name of the WSDL <code>message</code> type that this alias is to apply to.
-   * @param name the <code>QName</code> of the message type
-   */
-  public void setMessageType(QName name) {
-    _messageType = name;
-  }
-
-  /**
-   * Get the name of the WSDL <code>message</code> type that this alias it to apply to.
-   * @return the <code>QName</code> for the <code>messageType</code>
-   */
-  public QName getMessageType() {
-    return _messageType;
-  }
-
-  /**
-   * Set the name of the WSDL <code>part</code> that this alias is to apply to (within the
-   * specified <code>message</code>).
-   * @param name
-   * @see #setMessageType(QName)
-   */
-  public void setPart(String name) {
-    _part = name;
-  }
-
-  /**
-   * Get the name of the WSDL <code>part</code> that this alias is to apply to (within the
-   * specified <code>message</code>).
-   * @return the name of the part
-   * @see #getMessageType() 
-   */
-  public String getPart() {
-    return _part;
-  }
-
-  /**
-   * Set the <code>QName</code> of the property that this alias applies to.
-   * @param name the <code>QName</code> of the property.
-   */
-  public void setPropertyName(QName name) {
-    _propertyName = name;
-  }
-
-  /**
-   * Get the <code>QName</code> of the property that this alias applies to.
-   * @return the property <code>QName</code>
-   */
-  public QName getPropertyName() {
-    return _propertyName;
-  }
-
-  /**
-   * Set the location path query for this <code>OPropertyAlias</code>.  <em>No attempt is
-   * made at this point to determine whether the path is a valid location path.</em>
-   *
-   * @param string the location path
-   */
-  public void setQuery(Query string) {
-    _query = string;
-  }
-
-  /**
-   * Get the location path query for the <code>OPropertyAlias</code> as originally
-   * specified in the WSDL.
-   *
-   * @return the query
-   */
-  public Query getQuery() {
-    return _query;
-  }
-
-  /**
-   * @see javax.wsdl.extensions.ExtensibilityElement#setRequired(java.lang.Boolean)
-   */
-  public void setRequired(Boolean arg0) {
-  }
-
-  /**
-   * @see javax.wsdl.extensions.ExtensibilityElement#getRequired()
-   */
-  public Boolean getRequired() {
-    return Boolean.FALSE;
-  }
-  
-  /**
-   * Set the namespace context for the <code>&lt;propertyAlias&gt;</code> element that
-   * created this object.  It will be used later.
-   * @param n the <code>NSContext</code> that encapsulates the namespace context
-   */
-  public void setNSContext(NSContext n) {
-    _nsc = n;
-  }
-  
-  /**
-   * Get the namespace context for the <code>&lt;propertyAlias&gt;</code> element that
-   * created this object.
-   * @return the <code>NSContext</code> the encapsulates the namespace context
-   */
-  public NSContext getNSContext() {
-    return _nsc;
-  }
+public class PropertyAlias extends BpelObject4WSDL implements ExtensibilityElement, Serializable {
+
+    private static final long serialVersionUID = -1L;
+
+    public PropertyAlias(Element el) {
+        super(el);
+    }
+
+    /**
+     * Get the name of the WSDL <code>message</code> type that this alias it
+     * to apply to.
+     * 
+     * @return the <code>QName</code> for the <code>messageType</code>
+     */
+    public QName getMessageType() {
+        return getNamespaceContext().derefQName(getAttribute("messageType"));
+    }
+
+    /**
+     * Get the name of the WSDL <code>part</code> that this alias is to apply
+     * to (within the specified <code>message</code>).
+     * 
+     * @return the name of the part
+     * @see #getMessageType()
+     */
+    public String getPart() {
+        return getAttribute("part");
+    }
+
+    /**
+     * Get the <code>QName</code> of the property that this alias applies to.
+     * 
+     * @return the property <code>QName</code>
+     */
+    public QName getPropertyName() {
+        return getNamespaceContext().derefQName(getAttribute("propertyName"));
+    }
+
+    /**
+     * Get the location path query for the <code>OPropertyAlias</code> as
+     * originally specified in the WSDL.
+     * 
+     * @return the query
+     */
+    public Expression getQuery() {
+        return getFirstChild(Expression.class);
+    }
+
+    /**
+     * Get the namespace context for the <code>&lt;propertyAlias&gt;</code>
+     * element that created this object.
+     * 
+     * @return the <code>NSContext</code> the encapsulates the namespace
+     *         context
+     */
+    public NSContext getNSContext() {
+        return getNamespaceContext();
+    }
 }

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias11.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias11.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias11.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyAlias11.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,42 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * A BPEL 1.1 - implementation. Basically, the only difference is that the query is in an attribute.
+ * 
+ * @author Maciej Szefler - m s z e f l e r @ g m a i l . c o m
+ *
+ */
+public class PropertyAlias11 extends PropertyAlias {
+
+    private static final long serialVersionUID = 1L;
+
+    public PropertyAlias11(Element el) {
+        super(el);
+    }
+
+
+    @Override
+    public Expression getQuery() {
+        return getAttribute("query") != null ? new Query11(getElement(),getElement().getAttributeNode("query")) : null;
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyVal.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyVal.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyVal.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/PropertyVal.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,40 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import javax.xml.namespace.QName;
+
+import org.w3c.dom.Element;
+
+/**
+ * Assignment L/R-value defined in terms of a BPEL property.
+ */
+public class PropertyVal extends ToFrom {
+    public PropertyVal(Element el) {
+        super(el);
+    }
+
+    public String getVariable() {
+        return getAttribute("variable", null);
+    }
+
+    public QName getProperty() {
+        return getNamespaceContext().derefQName(getAttribute("property", null));
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,22 @@
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * A Query is nothing more than an expression with the expression-language in the "queryLanguage" attribute
+ * rather than the "expressionLanguage" attribute.
+ * 
+ * @author Maciej Szefler - m s z e f l e r @ g m a i l . c o m
+ *
+ */
+public class Query extends Expression {
+
+    public Query(Element el) {
+        super(el);
+    }
+
+    @Override
+    public String getExpressionLanguage() {
+        return getAttribute("queryLanguage", null);
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query11.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query11.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query11.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Query11.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,36 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+import org.w3c.dom.Node;
+
+/**
+ * A BPEL 1.1 Query, extends the 1.1 version of expression: {@link org.apache.ode.bpel.compiler.bom.Expression11}.
+ * 
+ * @author Maciej Szefler - m s z e f l e r @ g m a i l . c o m
+ *
+ */
+public class Query11 extends Expression11 {
+
+    public Query11(Element el, Node expression) {
+        super(el, expression);
+    }
+    
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReceiveActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReceiveActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReceiveActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReceiveActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,71 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import java.util.List;
+
+import javax.xml.namespace.QName;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of a BPEL <code>&lt;receive&gt;</code> activity.
+ */
+public class ReceiveActivity extends CreateInstanceActivity implements Communication {
+    private final CommunicationHelper _commHelper;
+
+    public ReceiveActivity(Element el) {
+        super(el);
+        _commHelper = new CommunicationHelper(el);
+    }
+
+    /**
+     * Get the optional message exchange identifier.
+     * 
+     * @return
+     */
+    public String getMessageExchangeId() {
+        return getAttribute("messageExchange", null);
+    }
+
+    /**
+     * Get the name of the variable that will hold the input message.
+     * 
+     * @return name of input message variable
+     */
+    public String getVariable() {
+        return getAttribute("variable", null);
+    }
+
+    public String getOperation() {
+        return _commHelper.getOperation();
+    }
+
+    public String getPartnerLink() {
+        return _commHelper.getPartnerLink();
+    }
+
+    public QName getPortType() {
+        return _commHelper.getPortType();
+    }
+
+    public List<Correlation> getCorrelations() {
+        return _commHelper.getCorrelations();
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReplyActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReplyActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReplyActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ReplyActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,81 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import java.util.List;
+
+import javax.xml.namespace.QName;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of the BPEL <code>&lt;reply&gt;</code> activity.
+ */
+public class ReplyActivity extends Activity implements Communication {
+    private final CommunicationHelper _commHelper;
+
+    public ReplyActivity(Element el) {
+        super(el);
+        _commHelper = new CommunicationHelper(el);
+    }
+
+    /**
+     * Get the optional message exchange identifier.
+     * 
+     * @return
+     */
+    public String getMessageExchangeId() {
+        return getAttribute("messageExchange", null);
+    }
+
+    /**
+     * Get the fault name with which to reply.
+     * 
+     * @return the fault name
+     */
+    public QName getFaultName() {
+        return getNamespaceContext().derefQName(getAttribute("faultName", null));
+    }
+
+    /**
+     * Get the variable containing the reply message.
+     * 
+     * @return name of variable containing the reply message
+     */
+    public String getVariable() {
+        return getAttribute("variable", null);
+    }
+
+    public String getOperation() {
+        return _commHelper.getOperation();
+    }
+
+    public String getPartnerLink() {
+        return _commHelper.getPartnerLink();
+    }
+
+    public QName getPortType() {
+        return _commHelper.getPortType();
+    }
+
+    public List<Correlation> getCorrelations() {
+        return _commHelper.getCorrelations();
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/RethrowActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/RethrowActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/RethrowActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/RethrowActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * BOM representation of the BPEL <code>&lt;rethrow&gt;</code> activity.
+ */
+public class RethrowActivity extends Activity {
+
+    public RethrowActivity(Element el) {
+        super(el);
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Scope.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Scope.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Scope.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Scope.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,184 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import java.util.Collections;
+import java.util.List;
+
+import org.apache.ode.utils.stl.CollectionsX;
+import org.apache.ode.utils.stl.MemberOfFunction;
+import org.w3c.dom.Element;
+
+/**
+ * Base-class for BPEL scope-like constructs. The term "scope-like construct"
+ * encompasses those structures that have the potential to declare either
+ * variables, event handlers, fault handlers, or compensation handlers. These
+ * scope like constructs include the scope activity, event handlers, the invoke
+ * activity, etc...
+ */
+public class Scope extends JoinFailureSuppressor {
+
+    public Scope(Element el) {
+        super(el);
+    }
+
+    /**
+     * Get the compensation handler for this scope.
+     * 
+     * @return the compensation handler
+     */
+    public CompensationHandler getCompensationHandler() {
+        return getFirstChild(CompensationHandler.class);
+    }
+
+    /**
+     * Gets the termination handler for this scope.
+     * 
+     * @return terminationHandler
+     */
+    public TerminationHandler getTerminationHandler() {
+        return getFirstChild(TerminationHandler.class);
+    }
+
+    /**
+     * Get the fault handler for this scope.
+     * 
+     * @return the fault handler
+     */
+    public FaultHandler getFaultHandler() {
+        return getFirstChild(FaultHandler.class);
+    }
+
+    /**
+     * Get correlation sets for this scope.
+     * 
+     * @return correlation sets for this scope.
+     */
+    public List<CorrelationSet> getCorrelationSetDecls() {
+        CorrelationSets csets = getFirstChild(CorrelationSets.class);
+        if (csets == null)
+            return Collections.emptyList();
+        return csets.getChildren(CorrelationSet.class);
+    }
+
+    /**
+     * Get a correlation set decleration.
+     * 
+     * @param setName
+     *            name of correlation set
+     * @return {@link CorrelationSet} of the fiven name.
+     */
+    public CorrelationSet getCorrelationSetDecl(final String setName) {
+        return CollectionsX.find_if(getCorrelationSetDecls(), new MemberOfFunction<CorrelationSet>() {
+
+            @Override
+            public boolean isMember(CorrelationSet cs) {
+                return setName.equals(cs.getName());
+            }
+
+        });
+
+    }
+
+    /**
+     * DOCUMENTME
+     * 
+     * @param varName
+     *            DOCUMENTME
+     * @return DOCUMENTME
+     */
+    public Variable getVariableDecl(final String varName) {
+        return CollectionsX.find_if(getVariables(), new MemberOfFunction<Variable>() {
+
+            @Override
+            public boolean isMember(Variable v) {
+                return varName.equals(v.getName());
+            }
+
+        });
+    }
+
+    /**
+     */
+    public List<Variable> getVariables() {
+        BpelObject vars = getFirstChild(Variables.class);
+        if (vars == null)
+            return Collections.emptyList();
+        return vars.getChildren(Variable.class);
+    }
+
+    /**
+     * Get an array of <code>OnAlarmEventHandler</code>s for this scope.
+     * 
+     * @return the <code>OnAlarmEventHandler</code>s
+     */
+    public List<OnAlarm> getAlarms() {
+        BpelObject eventHandlers = getFirstChild(Bpel20QNames.EVENTHANDLERS);
+        if (eventHandlers == null)
+            return Collections.emptyList();
+        return getChildren(OnAlarm.class);
+    }
+
+    /**
+     */
+    public List<OnEvent> getEvents() {
+        BpelObject eventHandlers = getFirstChild(Bpel20QNames.EVENTHANDLERS);
+        if (eventHandlers == null)
+            return Collections.emptyList();
+
+        return eventHandlers.getChildren(OnEvent.class);
+    }
+
+    /**
+     */
+    public boolean isVariableAccessSerialized() {
+        return false;
+    }
+
+    /**
+     * Get a partnerLink declared in this scope.
+     * 
+     * @param partnerLinkName
+     *            name of partner link
+     */
+    public PartnerLink getPartnerLink(final String partnerLinkName) {
+        return CollectionsX.find_if(getPartnerLinks(), new MemberOfFunction<PartnerLink>() {
+
+            @Override
+            public boolean isMember(PartnerLink pl) {
+                return partnerLinkName.equals(pl.getName());
+            }
+
+        });
+
+    }
+
+    /**
+     * Get all partnerLinks delcared in this scope.
+     * 
+     * @return set of declared {@link PartnerLink}s.
+     */
+    public List<PartnerLink> getPartnerLinks() {
+        PartnerLinks plinks = getFirstChild(PartnerLinks.class);
+        if (plinks == null)
+            return Collections.emptyList();
+        return plinks.getChildren(PartnerLink.class);
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,42 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * BPEL <code>&lt;scope&gt;</code> activity. A {@link ScopeActivity} is a
+ * scope-like construct (see {@link Scope}) and contains a single child
+ * activity.
+ */
+public class ScopeActivity extends ScopeLikeActivity {
+    public ScopeActivity(Element el) {
+        super(el);
+    }
+
+    /**
+     * Get the child activity for this {@link ScopeActivity}
+     * 
+     * @return the child {@link Activity}
+     */
+    public Activity getChildActivity() {
+        return getFirstChild(Activity.class);
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeLikeActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeLikeActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeLikeActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ScopeLikeActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,19 @@
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+public class ScopeLikeActivity extends Activity {
+
+    private Scope _scope;
+
+    public ScopeLikeActivity(Element el) {
+        super(el);
+        _scope = new Scope(el);
+    }
+
+    
+    public Scope getScope() {
+        return _scope;
+    }
+    
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/SequenceActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/SequenceActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/SequenceActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/SequenceActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,32 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * BPEL <code>&lt;sequence&gt;</code> activity.
+ * See {@link CompositeActivity} for methods used to manipulate child activities.
+ */
+public class SequenceActivity extends CompositeActivity {
+
+    public SequenceActivity(Element el) {
+        super(el);
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminateActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminateActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminateActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminateActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of the BPEL <code>&lt;terminate;&gt;</code> activity.
+ */
+public class TerminateActivity extends Activity {
+
+    public TerminateActivity(Element el) {
+        super(el);
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminationHandler.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminationHandler.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminationHandler.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/TerminationHandler.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,44 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of a BPEL termination handler.
+ */
+public class TerminationHandler extends BpelObject {
+
+
+  public TerminationHandler(Element el) {
+        super(el);
+    }
+
+/**
+   * Get the termination activity. This is the
+   * activity that gets activated if the termination handler
+   * is activated.
+   *
+   * @return termination activity.
+   */
+  public Activity getActivity() {
+      return getFirstChild(Activity.class);
+  }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ThrowActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ThrowActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ThrowActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ThrowActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,51 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import javax.xml.namespace.QName;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of the BPEL <code>&lt;throw&gt;</code> activity.
+ */
+public class ThrowActivity extends Activity {
+
+  public ThrowActivity(Element el) {
+        super(el);
+    }
+
+/**
+   * Get the thrown fault name.
+   *
+   * @return name of thrown fault
+   */
+  public QName getFaultName() {
+      return getNamespaceContext().derefQName(getAttribute("faultName", null));
+  }
+
+  /**
+   * Get the fault variable.
+   *
+   * @return name of variable containing fault data
+   */
+  public String getFaultVariable() {
+      return getAttribute("faultVariable",null);
+  }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/To.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/To.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/To.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/To.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,32 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+
+/**
+ * Marker interface for assignment L-values.
+ */
+public class To extends ToFrom {
+
+    public To(Element el) {
+        super(el);
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ToFrom.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ToFrom.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ToFrom.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/ToFrom.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,64 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+public class ToFrom extends BpelObject {
+
+    public ToFrom(Element el) {
+        super(el);
+    }
+    
+    public VariableVal getAsVariableVal() {
+        if (getAttribute("variable", null) != null)
+            return new VariableVal(getElement());
+        // TODO fix for 11
+        return null;
+    }
+    
+    public boolean isVariableVal() {
+        return getAsVariableVal() != null;
+    }
+    
+    public PartnerLinkVal getAsPartnerLinkVal() {
+        if (getAttribute("partnerLink",null) != null)
+            return new PartnerLinkVal(getElement());
+        return null;
+    }
+    
+    public boolean isPartnerLinkVal() {
+        return getAsPartnerLinkVal() != null;
+    }
+
+    public boolean isPropertyVal() {
+        return getAsPropertyVal() != null;
+    }
+
+    public PropertyVal getAsPropertyVal() {
+        if (getAttribute("property",null) != null)
+            return new PropertyVal(getElement());
+        return null;
+    }
+    
+    public Expression getAsExpression() {
+        return new Expression(getElement());
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variable.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variable.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variable.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variable.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,90 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import javax.xml.namespace.QName;
+
+import org.w3c.dom.Element;
+
+/**
+ * BPEL Variable declaration.
+ */
+public class Variable extends BpelObject {
+
+    public Variable(Element el) {
+        super(el);
+    }
+
+    public enum Kind {
+        SCHEMA, ELEMENT, MESSAGE
+    }
+
+    /**
+     * Get the name of the variable.
+     * 
+     * @return variable name
+     */
+    public String getName() {
+        return getAttribute("name", null);
+    }
+
+    /**
+     * Get the type name of this variable.
+     * 
+     * @return an XML element, XML schema type, or WSDL message type name.
+     */
+    public QName getTypeName() {
+        String typename = null;
+        switch (getKind()) {
+        case MESSAGE:
+            typename = getAttribute("messageType", null);
+            break;
+        case SCHEMA:
+            typename = getAttribute("type", null);
+            break;
+        case ELEMENT:
+            typename = getAttribute("element", null);
+        }
+
+        if (typename == null)
+            return null;
+
+        return getNamespaceContext().derefQName(typename);
+
+    }
+
+    /**
+     * Get the type of declaration; one of: {@link #TYPE_SCHEMA},
+     * {@link #TYPE_ELEMENT}, or {@link #TYPE_MESSAGE}.
+     * 
+     * @return type of variable decleration
+     */
+    public Kind getKind() {
+        if (getAttribute("messageType", null) != null)
+            return Kind.MESSAGE;
+        if (getAttribute("type", null) != null)
+            return Kind.SCHEMA;
+        if (getAttribute("element", null) != null)
+            return Kind.ELEMENT;
+
+        return null;
+
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,49 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * Assignment L/R-value defined by a location within a BPEL variable.
+ */
+public class VariableVal extends ToFrom {
+    public VariableVal(Element el) {
+        super(el);
+    }
+
+    /**
+     * Get the name of the variable.
+     * 
+     * @return variable name
+     */
+    public String getVariable() {
+        return getAttribute("variable", null);
+    }
+
+    /**
+     * Get the (optional) message part.
+     * 
+     * @return name of the message part, or <code>null</code>
+     */
+    public String getPart() {
+        return getAttribute("part", null);
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal11.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal11.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal11.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/VariableVal11.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,35 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+public class VariableVal11 extends VariableVal {
+
+    public VariableVal11(Element el) {
+        super(el);
+    }
+
+    public Expression getLocation() {
+        return (getAttribute("location") != null) 
+                ? new Expression11(getElement(), getElement().getAttributeNode("location"))
+                : null;
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variables.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variables.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variables.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/Variables.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,11 @@
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+public class Variables extends BpelObject {
+
+    public Variables(Element el) {
+        super(el);
+    }
+
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WaitActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WaitActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WaitActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WaitActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,50 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of the BPEL <code>&lt;wait&gt;</code> activity.
+ */
+public class WaitActivity extends Activity {
+ 
+  public WaitActivity(Element el) {
+        super(el);
+    }
+
+/**
+   * Get the for expression.
+   *
+   * @return Returns the for.
+   */
+  public Expression getFor() {
+      return  (Expression) getFirstChild(Bpel20QNames.FOR);
+  }
+
+  /**
+   * Get the "until" expression.
+   *
+   * @return the "until" expression
+   */
+  public Expression getUntil() {
+      return  (Expression) getFirstChild(Bpel20QNames.UNTIL);
+      
+  }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WhileActivity.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WhileActivity.java?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WhileActivity.java (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/WhileActivity.java Mon Oct 23 21:43:09 2006
@@ -0,0 +1,48 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.ode.bpel.compiler.bom;
+
+import org.w3c.dom.Element;
+
+/**
+ * Representation of the BPEL <code>&lt;while&gt;</code> activity.
+ */
+public class WhileActivity extends Activity {
+    public WhileActivity(Element el) {
+        super(el);
+    }
+
+    /**
+     * Get the child (repeated) activity.
+     * 
+     * @return repeated activity
+     */
+    public Activity getActivity() {
+        return getFirstChild(Activity.class);
+    }
+
+    /**
+     * Get the while condition.
+     * 
+     * @return the while condition
+     */
+    public Expression getCondition() {
+        return getFirstChild(Expression.class);
+    }
+}

Added: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/package.html
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/package.html?view=auto&rev=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/package.html (added)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/bom/package.html Mon Oct 23 21:43:09 2006
@@ -0,0 +1,39 @@
+<!--
+  ~ Licensed to the Apache Software Foundation (ASF) under one
+  ~ or more contributor license agreements.  See the NOTICE file
+  ~ distributed with this work for additional information
+  ~ regarding copyright ownership.  The ASF licenses this file
+  ~ to you under the Apache License, Version 2.0 (the
+  ~ "License"); you may not use this file except in compliance
+  ~ with the License.  You may obtain a copy of the License at
+  ~
+  ~    http://www.apache.org/licenses/LICENSE-2.0
+  ~
+  ~ Unless required by applicable law or agreed to in writing,
+  ~ software distributed under the License is distributed on an
+  ~ "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+  ~ KIND, either express or implied.  See the License for the
+  ~ specific language governing permissions and limitations
+  ~ under the License.
+  -->
+
+<html>
+<body>
+<p>
+The API for the BPEL Object Model (BOM), a domain-specific document 
+object model (DOM) that can represent BPEL v1.1 and BPEL v2.0 (OASIS) processes.
+While the BOM enforced strcutural constraints
+--for example that a process contain one root activity--
+it does not perform any static analysis, and may be used to produce processes
+that are invalid.
+It is also possible to use the BOM to build processes that do not conform to
+the BPEL XML Schema.
+This allows the BOM to be used in applications such a process design, where an
+incomplete or invalid process may need to be modeled.
+</p>
+
+<p>
+
+</p>
+</body>
+</html>

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/BpelExtensionSerializer.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/BaseSerializerDeserializer.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/BpelExtensionSerializer.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/BaseSerializerDeserializer.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/BpelExtensionSerializer.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/BaseSerializerDeserializer.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/BpelExtensionSerializer.java Mon Oct 23 21:43:09 2006
@@ -16,13 +16,22 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
+import java.io.PrintWriter;
+
+import org.apache.ode.bpel.compiler.bom.BpelObject4WSDL;
+import org.apache.ode.bpel.compiler.bom.BpelObjectFactory;
 import org.apache.ode.utils.DOMUtils;
 import org.apache.ode.utils.msg.MessageBundle;
 import com.ibm.wsdl.util.xml.XPathUtils;
 
+import javax.wsdl.Definition;
 import javax.wsdl.WSDLException;
+import javax.wsdl.extensions.ExtensibilityElement;
+import javax.wsdl.extensions.ExtensionDeserializer;
+import javax.wsdl.extensions.ExtensionRegistry;
+import javax.wsdl.extensions.ExtensionSerializer;
 import javax.xml.namespace.QName;
 
 import org.w3c.dom.Attr;
@@ -30,10 +39,44 @@
 import org.w3c.dom.Node;
 
 /**
- * Base class for WSDL4J serializers.
+ * BPEL extension (partnerLinkType/propertyAlias) serializer for WSDL4J.
  */
-class BaseSerializerDeserializer {
+public class BpelExtensionSerializer implements ExtensionDeserializer, ExtensionSerializer {
   protected static final Messages __msgs = MessageBundle.getMessages(Messages.class);
+
+  private BpelObjectFactory _factory;
+
+  public BpelExtensionSerializer(BpelObjectFactory factory) {
+      _factory = factory;
+  }
+
+  /**
+   * @see javax.wsdl.extensions.ExtensionSerializer#marshall(java.lang.Class,
+   *      javax.xml.namespace.QName,
+   *      javax.wsdl.extensions.ExtensibilityElement, java.io.PrintWriter,
+   *      javax.wsdl.Definition, javax.wsdl.extensions.ExtensionRegistry)
+   */
+  public void marshall(Class arg0, QName arg1, ExtensibilityElement arg2, PrintWriter arg3, Definition arg4,
+          ExtensionRegistry arg5) throws WSDLException {
+      throw new UnsupportedOperationException();
+  }
+
+  /**
+   * @see javax.wsdl.extensions.ExtensionDeserializer#unmarshall(java.lang.Class,
+   *      javax.xml.namespace.QName, org.w3c.dom.Element,
+   *      javax.wsdl.Definition, javax.wsdl.extensions.ExtensionRegistry)
+   */
+  public ExtensibilityElement unmarshall(Class clsType, QName eltype, Element el, Definition def, ExtensionRegistry extReg)
+          throws WSDLException {
+
+      validateExtensibilityElementContext(el);
+
+      BpelObject4WSDL obj =  (BpelObject4WSDL) _factory.createBpelObject(el);
+      obj.setElementType(eltype);
+      obj.setRequired(false);  // ? what does this do 
+      obj.setTargetNamespace(def.getTargetNamespace());
+      return obj;
+  }
 
   /**
    * Dereference a qualified name given in the "ns:name" form using the namespace

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPEL.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Definition4BPEL.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPEL.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Definition4BPEL.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPEL.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Definition4BPELImpl.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPELImpl.java Mon Oct 23 21:43:09 2006
@@ -16,8 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
+import org.apache.ode.bpel.compiler.bom.PartnerLinkType;
+import org.apache.ode.bpel.compiler.bom.Property;
+import org.apache.ode.bpel.compiler.bom.PropertyAlias;
 import org.apache.ode.utils.stl.CollectionsX;
 import org.apache.ode.utils.stl.MemberOfFunction;
 import org.w3c.dom.Element;

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPartnerLinkTypeException.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPartnerLinkTypeException.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPartnerLinkTypeException.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPartnerLinkTypeException.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPartnerLinkTypeException.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPartnerLinkTypeException.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPartnerLinkTypeException.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.WSDLException;
 

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyAliasException.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPropertyAliasException.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyAliasException.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPropertyAliasException.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyAliasException.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPropertyAliasException.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyAliasException.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.WSDLException;
 

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyException.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPropertyException.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyException.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPropertyException.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyException.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelPropertyException.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelPropertyException.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.WSDLException;
 

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelRoleException.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelRoleException.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelRoleException.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelRoleException.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelRoleException.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/InvalidBpelRoleException.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/InvalidBpelRoleException.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.WSDLException;
 

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Messages.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Messages.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Messages.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Messages.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Messages.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Messages.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Messages.java Mon Oct 23 21:43:09 2006
@@ -17,7 +17,7 @@
  * under the License.
  */
 
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import org.apache.ode.utils.msg.MessageBundle;
 

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactory4BPEL.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactory4BPEL.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactory4BPEL.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactory4BPEL.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactory4BPEL.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactory4BPEL.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactory4BPEL.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.Definition;
 import javax.wsdl.xml.WSDLReader;

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL11.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryBPEL11.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL11.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryBPEL11.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL11.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryBPEL11.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL11.java Mon Oct 23 21:43:09 2006
@@ -16,9 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
-
-import org.apache.ode.bom.api.Constants;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.Definition;
 import javax.wsdl.Types;
@@ -26,33 +24,39 @@
 import javax.wsdl.factory.WSDLFactory;
 import javax.xml.namespace.QName;
 
+import org.apache.ode.bpel.compiler.bom.BpelObjectFactory;
+import org.apache.ode.bpel.compiler.bom.Constants;
+
 /**
  * Factory for {@link WSDLFactory} objects that are pre-configured to handle
  * BPEL 2.0 extension elements.
  */
 public class WSDLFactoryBPEL11 extends WSDLFactoryImpl implements WSDLFactory4BPEL {
 
-  public WSDLFactoryBPEL11() {
-    super(Constants.NS_BPEL4WS_2003_03, Constants.NS_BPEL4WS_PARTNERLINK_2003_05);
-  }
-
-  public static WSDLFactory newInstance() {
-    return new WSDLFactoryBPEL11();
-  }
-
-  public ExtensionRegistry newPopulatedExtensionRegistry() {
-    ExtensionRegistry extRegistry;
-    extRegistry = super.newPopulatedExtensionRegistry();
-    extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "property"),
-                             new PropertySerializer());
-    extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "propertyAlias"),
-                             new PropertyAliasSerializer_11());
-    extRegistry.registerDeserializer(Types.class, XMLSchemaType.QNAME,
-                             new XMLSchemaTypeSerializer());
-    extRegistry.registerDeserializer(Definition.class, new QName(Constants.NS_BPEL4WS_PARTNERLINK_2003_05, "partnerLinkType"),
-        new PartnerLinkTypeSerializer_1_1(Constants.NS_BPEL4WS_PARTNERLINK_2003_05));
-    return extRegistry;
+    private BpelObjectFactory _bomf;
+
+    private BpelExtensionSerializer _bs;
+
+    public WSDLFactoryBPEL11() {
+        super(Constants.NS_BPEL4WS_2003_03, Constants.NS_BPEL4WS_PARTNERLINK_2003_05);
+        _bomf = BpelObjectFactory.getInstance();
+        _bs = new BpelExtensionSerializer(_bomf);
+    }
+
+    public static WSDLFactory newInstance() {
+        return new WSDLFactoryBPEL11();
+    }
+
+    public ExtensionRegistry newPopulatedExtensionRegistry() {
+        ExtensionRegistry extRegistry;
+        extRegistry = super.newPopulatedExtensionRegistry();
+        extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "property"), _bs);
+        extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "propertyAlias"), _bs);
+        extRegistry.registerDeserializer(Types.class, XMLSchemaType.QNAME, new XMLSchemaTypeSerializer());
+        extRegistry.registerDeserializer(Definition.class, new QName(Constants.NS_BPEL4WS_PARTNERLINK_2003_05,
+                "partnerLinkType"), _bs);
+        return extRegistry;
 
-  }
+    }
 
 }

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL20.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryBPEL20.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL20.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryBPEL20.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL20.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryBPEL20.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryBPEL20.java Mon Oct 23 21:43:09 2006
@@ -16,9 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
-import org.apache.ode.bom.api.Constants;
+import org.apache.ode.bpel.compiler.bom.BpelObjectFactory;
+import org.apache.ode.bpel.compiler.bom.Constants;
 
 import javax.wsdl.Definition;
 import javax.wsdl.Types;
@@ -32,27 +33,29 @@
  */
 public class WSDLFactoryBPEL20 extends WSDLFactoryImpl implements WSDLFactory4BPEL {
 
-  public WSDLFactoryBPEL20() {
-    super(Constants.NS_WSBPEL_2004_03, Constants.NS_WSBPEL_PARTNERLINK_2004_03);
-  }
-
-  public static WSDLFactory newInstance() {
-    return new WSDLFactoryBPEL20();
-  }
-
-  public ExtensionRegistry newPopulatedExtensionRegistry() {
-    ExtensionRegistry extRegistry;
-    extRegistry = super.newPopulatedExtensionRegistry();
-    extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "property"),
-                             new PropertySerializer());
-    extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "propertyAlias"),
-                             new PropertyAliasSerializer_20());
-    extRegistry.registerDeserializer(Types.class, XMLSchemaType.QNAME,
-                             new XMLSchemaTypeSerializer());
-    extRegistry.registerDeserializer(Definition.class, new QName(Constants.NS_WSBPEL_PARTNERLINK_2004_03, "partnerLinkType"),
-        new PartnerLinkTypeSerializer_2_0(Constants.NS_WSBPEL_PARTNERLINK_2004_03));
-    return extRegistry;
+    private BpelObjectFactory _bomf;
+    private BpelExtensionSerializer _bs;
 
-  }
+    public WSDLFactoryBPEL20() {
+        super(Constants.NS_WSBPEL_2004_03, Constants.NS_WSBPEL_PARTNERLINK_2004_03);
+        _bomf = BpelObjectFactory.getInstance();
+        _bs = new BpelExtensionSerializer(_bomf);
+    }
+
+    public static WSDLFactory newInstance() {
+        return new WSDLFactoryBPEL20();
+    }
+
+    public ExtensionRegistry newPopulatedExtensionRegistry() {
+        ExtensionRegistry extRegistry;
+        extRegistry = super.newPopulatedExtensionRegistry();
+        extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "property"),_bs);
+        extRegistry.registerDeserializer(Definition.class, new QName(_bpwsNS, "propertyAlias"), _bs);
+        extRegistry.registerDeserializer(Types.class, XMLSchemaType.QNAME, new XMLSchemaTypeSerializer());
+        extRegistry.registerDeserializer(Definition.class, new QName(Constants.NS_WSBPEL_PARTNERLINK_2004_03,
+                "partnerLinkType"),_bs);
+        return extRegistry;
+
+    }
 
 }

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryImpl.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryImpl.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryImpl.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryImpl.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryImpl.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLFactoryImpl.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLFactoryImpl.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.Definition;
 import javax.wsdl.WSDLException;

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLReaderImpl.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLReaderImpl.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLReaderImpl.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLReaderImpl.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLReaderImpl.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/WSDLReaderImpl.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLReaderImpl.java Mon Oct 23 21:43:09 2006
@@ -1,4 +1,4 @@
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.WSDLException;
 import javax.wsdl.factory.WSDLFactory;

Propchange: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/WSDLReaderImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaType.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/XMLSchemaType.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaType.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/XMLSchemaType.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaType.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/XMLSchemaType.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaType.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import java.io.Serializable;
 

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaTypeSerializer.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/XMLSchemaTypeSerializer.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaTypeSerializer.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/XMLSchemaTypeSerializer.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaTypeSerializer.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/XMLSchemaTypeSerializer.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/XMLSchemaTypeSerializer.java Mon Oct 23 21:43:09 2006
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import org.apache.ode.utils.DOMUtils;
 

Copied: incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationMessageTest.java (from r453648, incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationMessageTest.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationMessageTest.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationMessageTest.java&r1=453648&p2=incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationMessageTest.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationMessageTest.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationMessageTest.java Mon Oct 23 21:43:09 2006
@@ -17,8 +17,9 @@
  * under the License.
  */
 
-package org.apache.ode.bpel.capi;
+package org.apache.ode.bpel.compiler;
 
+import org.apache.ode.bpel.compiler.api.CompilationMessage;
 import org.apache.ode.utils.msg.MessageBundle;
 
 import java.util.Locale;

Copied: incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages.java (from r453648, incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationTestMessages.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationTestMessages.java&r1=453648&p2=incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationTestMessages.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages.java Mon Oct 23 21:43:09 2006
@@ -17,7 +17,10 @@
  * under the License.
  */
 
-package org.apache.ode.bpel.capi;
+package org.apache.ode.bpel.compiler;
+
+import org.apache.ode.bpel.compiler.api.CompilationMessage;
+import org.apache.ode.bpel.compiler.api.CompilationMessageBundle;
 
 public class CompilationTestMessages extends CompilationMessageBundle {
 

Copied: incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages_de.java (from r453648, incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationTestMessages_de.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages_de.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationTestMessages_de.java&r1=453648&p2=incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages_de.java&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-api/src/test/java/org/apache/ode/bpel/capi/CompilationTestMessages_de.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/CompilationTestMessages_de.java Mon Oct 23 21:43:09 2006
@@ -17,7 +17,9 @@
  * under the License.
  */
 
-package org.apache.ode.bpel.capi;
+package org.apache.ode.bpel.compiler;
+
+import org.apache.ode.bpel.compiler.api.CompilationMessage;
 
 public class CompilationTestMessages_de extends CompilationTestMessages {
 

Modified: incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java?view=diff&rev=467239&r1=467238&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/StaticCheckTCase.java Mon Oct 23 21:43:09 2006
@@ -19,10 +19,11 @@
 package org.apache.ode.bpel.compiler;
 
 import junit.framework.TestCase;
-import org.apache.ode.bom.wsdl.Definition4BPEL;
-import org.apache.ode.bpel.capi.CompilationException;
-import org.apache.ode.bpel.capi.CompilationMessage;
-import org.apache.ode.bpel.capi.CompileListener;
+
+import org.apache.ode.bpel.compiler.api.CompilationException;
+import org.apache.ode.bpel.compiler.api.CompilationMessage;
+import org.apache.ode.bpel.compiler.api.CompileListener;
+import org.apache.ode.bpel.compiler.wsdl.Definition4BPEL;
 import org.apache.ode.utils.fs.FileUtils;
 import org.xml.sax.InputSource;
 

Modified: incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java?view=diff&rev=467239&r1=467238&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler/WSDLRegistryTest.java Mon Oct 23 21:43:09 2006
@@ -18,9 +18,9 @@
  */
 package org.apache.ode.bpel.compiler;
 
-import org.apache.ode.bom.wsdl.Definition4BPEL;
-import org.apache.ode.bom.wsdl.WSDLFactory4BPEL;
-import org.apache.ode.bom.wsdl.WSDLFactoryBPEL11;
+import org.apache.ode.bpel.compiler.wsdl.Definition4BPEL;
+import org.apache.ode.bpel.compiler.wsdl.WSDLFactory4BPEL;
+import org.apache.ode.bpel.compiler.wsdl.WSDLFactoryBPEL11;
 import org.apache.ode.utils.xsd.SchemaModel;
 
 import java.net.URL;

Modified: incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java?view=diff&rev=467239&r1=467238&r2=467239
==============================================================================
--- incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/test/java/org/apache/ode/bpel/compiler_2_0/GoodCompileTCase.java Mon Oct 23 21:43:09 2006
@@ -19,9 +19,9 @@
 package org.apache.ode.bpel.compiler_2_0;
 
 import junit.framework.TestCase;
-import org.apache.ode.bpel.capi.CompilationMessage;
-import org.apache.ode.bpel.capi.CompileListener;
 import org.apache.ode.bpel.compiler.BpelC;
+import org.apache.ode.bpel.compiler.api.CompilationMessage;
+import org.apache.ode.bpel.compiler.api.CompileListener;
 import org.apache.ode.utils.StreamUtils;
 
 import java.io.ByteArrayOutputStream;
--- incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Definition4BPEL.java (original)
+++ incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPEL.java Mon Oct 23 21:43:09 2006
@@ -16,10 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ode.bom.wsdl;
+package org.apache.ode.bpel.compiler.wsdl;
 
 import javax.wsdl.Definition;
 import javax.xml.namespace.QName;
+
+import org.apache.ode.bpel.compiler.bom.PartnerLinkType;
+import org.apache.ode.bpel.compiler.bom.Property;
+import org.apache.ode.bpel.compiler.bom.PropertyAlias;
+
 import java.util.List;
 
 /**
@@ -36,9 +41,9 @@
   List<PartnerLinkType> getPartnerLinkTypes();
 
   /**
    * Get a list of the defined {@link org.apache.ode.bom.wsdl.Property}s.
    *
    * @return {@link List} of {@link org.apache.ode.bom.wsdl.Property} objects
    */
   List<Property> getProperties();
 
@@ -36,9 +41,9 @@
 
   /**
-   * Get a list of the defined {@link org.apache.ode.bom.wsdl.Property}s.
+   * Get a list of the defined {@link org.apache.ode.bpel.compiler.bom.Property}s.
    *
@@ -36,9 +41,9 @@
    *
-   * @return {@link List} of {@link org.apache.ode.bom.wsdl.Property} objects
+   * @return {@link List} of {@link org.apache.ode.bpel.compiler.bom.Property} objects
    */
   List<Property> getProperties();

Copied: incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPELImpl.java (from r448015, incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Definition4BPELImpl.java)
URL: http://svn.apache.org/viewvc/incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPELImpl.java?view=diff&rev=467239&p1=incubator/ode/trunk/bpel-bom/src/main/java/org/apache/ode/bom/wsdl/Definition4BPELImpl.java&r1=448015&p2=incubator/ode/trunk/bpel-compiler/src/main/java/org/apache/ode/bpel/compiler/wsdl/Definition4BPELImpl.java&r2=467239
==============================================================================